Index: trip-planner/src/main/java/finki/diplomska/tripplanner/models/Planner.java
===================================================================
--- trip-planner/src/main/java/finki/diplomska/tripplanner/models/Planner.java	(revision 1ad8e64a349fcc7c996155279b16efc2cfe001dd)
+++ trip-planner/src/main/java/finki/diplomska/tripplanner/models/Planner.java	(revision 84d0fbb56bfbe319ba63e3327f1777ac5d841f83)
@@ -1,6 +1,6 @@
 package finki.diplomska.tripplanner.models;
 
+import com.fasterxml.jackson.annotation.JsonIgnore;
 import lombok.*;
-import reactor.util.annotation.Nullable;
 
 import javax.persistence.*;
@@ -10,5 +10,4 @@
 @Data
 @Table(name = "planners")
-@NoArgsConstructor
 @AllArgsConstructor
 @Getter
@@ -34,9 +33,15 @@
     private List<Location> locationList;
 
+    @ManyToOne(fetch = FetchType.EAGER)
+    private User user;
 
-    public Planner(String name, String description, List<Location> locationList){
+    public Planner(){
+    }
+
+    public Planner(String name, String description, List<Location> locationList, User user){
             this.name = name;
             this.description = description;
             this.locationList = locationList;
+            this.user = user;
     }
 
Index: trip-planner/src/main/java/finki/diplomska/tripplanner/models/dto/PlannerDto.java
===================================================================
--- trip-planner/src/main/java/finki/diplomska/tripplanner/models/dto/PlannerDto.java	(revision 1ad8e64a349fcc7c996155279b16efc2cfe001dd)
+++ trip-planner/src/main/java/finki/diplomska/tripplanner/models/dto/PlannerDto.java	(revision 84d0fbb56bfbe319ba63e3327f1777ac5d841f83)
@@ -9,8 +9,10 @@
     private String name;
     private String description;
+    private String user;
 
-    public PlannerDto(String name, String description) {
+    public PlannerDto(String name, String description, String user) {
         this.name = name;
         this.description = description;
+        this.user = user;
     }
 }
Index: trip-planner/src/main/java/finki/diplomska/tripplanner/models/dto/UserDto.java
===================================================================
--- trip-planner/src/main/java/finki/diplomska/tripplanner/models/dto/UserDto.java	(revision 1ad8e64a349fcc7c996155279b16efc2cfe001dd)
+++ trip-planner/src/main/java/finki/diplomska/tripplanner/models/dto/UserDto.java	(revision 84d0fbb56bfbe319ba63e3327f1777ac5d841f83)
@@ -20,11 +20,10 @@
     private Date update_At;
 
-    public UserDto(String username, String fullName, String password, String confirmPassword, Date create_At, Date update_At) {
+    public UserDto(String username, String fullName, String password, String confirmPassword) {
         this.username = username;
         this.fullName = fullName;
         this.password = password;
         this.confirmPassword = confirmPassword;
-        this.create_At = create_At;
-        this.update_At = update_At;
+
     }
 }

Index: trip-planner/src/main/java/finki/diplomska/tripplanner/models/User.java
===================================================================
--- trip-planner/src/main/java/finki/diplomska/tripplanner/models/User.java	(revision 1ad8e64a349fcc7c996155279b16efc2cfe001dd)
+++ trip-planner/src/main/java/finki/diplomska/tripplanner/models/User.java	(revision 84d0fbb56bfbe319ba63e3327f1777ac5d841f83)
@@ -11,6 +11,8 @@
 import javax.validation.constraints.Email;
 import javax.validation.constraints.NotBlank;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
+import java.util.List;
 
 @Entity
@@ -38,9 +40,18 @@
     private Date update_At;
 
-    //OneToMany with Project
+    //OneToMany with Planners
+    @OneToMany(cascade = CascadeType.REFRESH, fetch = FetchType.EAGER, mappedBy = "user", orphanRemoval = true)
+    @JsonIgnore
+    private List<Planner> planners = new ArrayList<>();
 
     public User() {
     }
 
+    public User(String username, String fullName, String password, String confirmPassword) {
+        this.username = username;
+        this.fullName = fullName;
+        this.password = password;
+        this.confirmPassword = confirmPassword;
+    }
 
     @PrePersist